package com.huiju.welcome.controller;


import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.huiju.welcome.common.base.BaseController;
import com.huiju.welcome.common.base.ResponseBean;
import com.huiju.welcome.model.SysDict;
import com.huiju.welcome.service.ISysDictService;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.util.StringUtils;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.bind.annotation.RestController;

/**
 * <p>
    * 字典表 前端控制器
    * </p>
 *
 * @author jobob
 * @since 2019-07-16
 */
@RestController
@RequestMapping("/")
public class SysDictController extends BaseController {

    private final Logger logger = LoggerFactory.getLogger(SysDictController.class);

    @Autowired
    private ISysDictService iSysDictService;


    /**
     * 保存对象
     * @param sysDict 实体对象
     * @return
     */
    @RequestMapping(value="/sysDict/add",method= RequestMethod.POST)
    public ResponseBean tpShopImgAdd(@RequestBody SysDict sysDict){
        ResponseBean responseBean = new ResponseBean();
        try {
            if (iSysDictService.save(sysDict)){
                responseBean.addSuccess("success");
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            logger.error("sysDictAdd -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 根据id删除对象
     * @param id  实体ID
     */
    @ResponseBody
    @RequestMapping(value="/sysDict/delete/{id}", method= RequestMethod.DELETE)
    public ResponseBean sysDictDelete(@PathVariable Integer id){
        ResponseBean responseBean = new ResponseBean();
        try {
            if(iSysDictService.removeById(id)){
                responseBean.addSuccess("success");
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            logger.error("sysDictDelete -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 修改对象
     * @param sysDict 实体对象
     * @return
     */
    @RequestMapping(value="/sysDict/update",method= RequestMethod.PUT)
    public ResponseBean tpShopImgUpdate(@RequestBody SysDict sysDict){
        ResponseBean responseBean = new ResponseBean();
        try {
            if (iSysDictService.updateById(sysDict)){
                responseBean.addSuccess("success");
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            logger.error("sysDictUpdate -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 根据id查询对象
     * @param id  实体ID
     */
    @RequestMapping(value="/sysDict/get/{id}",method= RequestMethod.GET)
    public ResponseBean tpShopImgGet(@PathVariable Integer id){
        ResponseBean responseBean = new ResponseBean();
        try {
            responseBean.addSuccess(iSysDictService.getById(id));
        }catch (Exception e){
            logger.error("sysDictDelete -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }
    
    /**
     * 根据TYPE查询对象
     * @param type  实体type
     */
    @RequestMapping(value="/miniapp/dicts",method= RequestMethod.GET)
    public ResponseBean getDictByType(String type){
        ResponseBean responseBean = new ResponseBean();
        try {
            QueryWrapper<SysDict> queryWrapper = new QueryWrapper<>();
            if(!StringUtils.isEmpty(type)){
                queryWrapper.eq("type",type);
            }
            queryWrapper.orderByAsc("type");
            queryWrapper.orderByDesc("sort");
            queryWrapper.orderByDesc("create_date");
            
            responseBean.addSuccess(iSysDictService.list(queryWrapper));
        }catch (Exception e){
            logger.error("getByType -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }
}
