package com.huiju.welcome.controller;

import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.huiju.welcome.common.base.BaseController;
import com.huiju.welcome.common.base.ResponseBean;
import com.huiju.welcome.model.SysUser;
import com.huiju.welcome.model.TaGoodsOrders;
import com.huiju.welcome.model.TaGoodsOrdersDetail;
import com.huiju.welcome.model.TdGoodsType;
import com.huiju.welcome.service.ISysUserService;
import com.huiju.welcome.service.ITaGoodsOrdersDetailService;
import com.huiju.welcome.service.ITaGoodsOrdersService;
import com.huiju.welcome.utils.JWTUtils;
import com.huiju.welcome.utils.StatusUtils;
import com.huiju.welcome.utils.StringUtils;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import io.swagger.models.auth.In;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletRequest;
import java.time.LocalDateTime;
import java.util.List;


/**
 * <p>
    *  前端控制器
    * </p>
 *
 * @author jobob
 * @since 2019-07-16
 */
@RestController
@RequestMapping("/")
public class TaGoodsOrdersController extends BaseController {

    private final Logger logger = LoggerFactory.getLogger(TaGoodsOrdersController.class);

    @Autowired
    public ITaGoodsOrdersService iTaGoodsOrdersService;
    @Autowired
    public ITaGoodsOrdersDetailService iTaGoodsOrdersDetailService;
    @Autowired
    public ISysUserService iSysUserService;


    /**
     * 保存对象
     * @param taGoodsOrders 实体对象
     * @return
     */
    @RequestMapping(value="/taGoodsOrders/add",method= RequestMethod.POST)
    public ResponseBean taGoodsOrdersAdd(@RequestBody TaGoodsOrders taGoodsOrders, HttpServletRequest request){
        ResponseBean responseBean = new ResponseBean();
        try {
            String userId = JWTUtils.getSubject(request);
            SysUser sysUser = iSysUserService.getById(userId);
            taGoodsOrders.setUserId(sysUser.getUserId());
            taGoodsOrders.setUserName(sysUser.getUsername());
            taGoodsOrders.setUserType(sysUser.getUserIdentity());
            taGoodsOrders.setCreateDate(LocalDateTime.now());
            taGoodsOrders.setStatus(StatusUtils.Normal);
            Integer recId = iTaGoodsOrdersService.getRecIdByCustomerIdCurrentDate(taGoodsOrders.getCustomerId());
            if(recId != null){
                taGoodsOrders.setRecId(recId);
            }
            Boolean flag = iTaGoodsOrdersService.save(taGoodsOrders);

            Boolean flagDetail = false;
            List<TaGoodsOrdersDetail> detailList = taGoodsOrders.getDetailList();
            detailList.stream().forEach(e -> {
                e.setOrdersId(taGoodsOrders.getOrdersId());
                e.setCreateDate(LocalDateTime.now());
            });
            flagDetail = iTaGoodsOrdersDetailService.saveBatch(detailList);
            if (flag&&flagDetail){
                responseBean.addSuccess(taGoodsOrders);
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            logger.error("taGoodsOrdersAdd -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 根据id删除对象
     * @param id  实体ID
     */
    @ResponseBody
    @RequestMapping(value="/taGoodsOrders/delete/{id}", method= RequestMethod.DELETE)
    public ResponseBean taGoodsOrdersDelete(@PathVariable Integer id){
        ResponseBean responseBean = new ResponseBean();
        try {
            if(iTaGoodsOrdersService.removeById(id)){
                responseBean.addSuccess("success");
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            logger.error("taGoodsOrdersDelete -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 修改对象
     * @param taGoodsOrders 实体对象
     * @return
     */
    @RequestMapping(value="/taGoodsOrders/update",method= RequestMethod.PUT)
    public ResponseBean taGoodsOrdersUpdate(@RequestBody TaGoodsOrders taGoodsOrders){
        ResponseBean responseBean = new ResponseBean();
        try {
            if (iTaGoodsOrdersService.updateById(taGoodsOrders)){
                responseBean.addSuccess("success");
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            logger.error("taGoodsOrdersUpdate -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 根据id查询对象
     * @param id  实体ID
     */
    @RequestMapping(value="/taGoodsOrders/get/{id}",method= RequestMethod.GET)
    public ResponseBean taGoodsOrdersGet(@PathVariable Integer id){
        ResponseBean responseBean = new ResponseBean();
        try {
            responseBean.addSuccess(iTaGoodsOrdersService.getById(id));
        }catch (Exception e){
            logger.error("taGoodsOrdersDelete -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    @ApiOperation(value = "商品订单列表", notes = "商品订单列表")
    @ApiImplicitParams({
    })
    @RequestMapping(value = "/taGoodsOrders", method = RequestMethod.GET)
    public ResponseBean goodsOrderList(@RequestParam(defaultValue = "1") int pageNum,
                                 @RequestParam(defaultValue = "10") int pageSize,
                                 @RequestParam(value = "userName",required = false) String userName,
                                       @RequestParam(value = "userId",required = false) Integer userId,
                                       @RequestParam(value = "ordersNo",required = false) String ordersNo,
                                       @RequestParam(value = "customerId",required = true) Integer customerId) {
        IPage<TaGoodsOrders> pg = new Page<>(pageNum, pageSize);

        ResponseBean userManagement= iTaGoodsOrdersService.goodsOrderList(pg,userName,userId,ordersNo,customerId);

        return userManagement;
    }


}
